@@ -38,7 +38,10 @@ __all__ = (
     "ListFeaturesPaginatorName",
     "ListLaunchesPaginatorName",
     "ListProjectsPaginatorName",
+    "ListSegmentReferencesPaginatorName",
+    "ListSegmentsPaginatorName",
     "ProjectStatusType",
+    "SegmentReferenceResourceTypeType",
     "VariationValueTypeType",
     "CloudWatchEvidentlyServiceName",
     "ServiceName",
@@ -74,7 +77,10 @@ ListExperimentsPaginatorName = Literal["list_experiments"]
 ListFeaturesPaginatorName = Literal["list_features"]
 ListLaunchesPaginatorName = Literal["list_launches"]
 ListProjectsPaginatorName = Literal["list_projects"]
+ListSegmentReferencesPaginatorName = Literal["list_segment_references"]
+ListSegmentsPaginatorName = Literal["list_segments"]
 ProjectStatusType = Literal["AVAILABLE", "UPDATING"]
+SegmentReferenceResourceTypeType = Literal["EXPERIMENT", "LAUNCH"]
 VariationValueTypeType = Literal["BOOLEAN", "DOUBLE", "LONG", "STRING"]
 CloudWatchEvidentlyServiceName = Literal["evidently"]
 ServiceName = Literal[
@@ -147,6 +153,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -257,6 +264,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -313,11 +321,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -397,7 +407,14 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
-PaginatorName = Literal["list_experiments", "list_features", "list_launches", "list_projects"]
+PaginatorName = Literal[
+    "list_experiments",
+    "list_features",
+    "list_launches",
+    "list_projects",
+    "list_segment_references",
+    "list_segments",
+]
 RegionName = Literal[
     "ap-northeast-1",
     "ap-southeast-1",
