@@ -27,6 +27,7 @@ from .literals import (
     LaunchStatusType,
     LaunchStopDesiredStateType,
     ProjectStatusType,
+    SegmentReferenceResourceTypeType,
     VariationValueTypeType,
 )
 
@@ -48,10 +49,13 @@ __all__ = (
     "OnlineAbConfigTypeDef",
     "TreatmentConfigTypeDef",
     "LaunchGroupConfigTypeDef",
+    "CreateSegmentRequestRequestTypeDef",
+    "SegmentTypeDef",
     "DeleteExperimentRequestRequestTypeDef",
     "DeleteFeatureRequestRequestTypeDef",
     "DeleteLaunchRequestRequestTypeDef",
     "DeleteProjectRequestRequestTypeDef",
+    "DeleteSegmentRequestRequestTypeDef",
     "EvaluateFeatureRequestRequestTypeDef",
     "VariableValueTypeDef",
     "EvaluationRuleTypeDef",
@@ -67,6 +71,7 @@ __all__ = (
     "GetFeatureRequestRequestTypeDef",
     "GetLaunchRequestRequestTypeDef",
     "GetProjectRequestRequestTypeDef",
+    "GetSegmentRequestRequestTypeDef",
     "LaunchExecutionTypeDef",
     "LaunchGroupTypeDef",
     "PaginatorConfigTypeDef",
@@ -75,19 +80,22 @@ __all__ = (
     "ListLaunchesRequestRequestTypeDef",
     "ListProjectsRequestRequestTypeDef",
     "ProjectSummaryTypeDef",
+    "ListSegmentReferencesRequestRequestTypeDef",
+    "RefResourceTypeDef",
+    "ListSegmentsRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "MetricDefinitionConfigTypeDef",
     "MetricDefinitionTypeDef",
     "S3DestinationConfigTypeDef",
     "S3DestinationTypeDef",
     "PutProjectEventsResultEntryTypeDef",
-    "ScheduledSplitConfigTypeDef",
-    "ScheduledSplitTypeDef",
+    "SegmentOverrideTypeDef",
     "StartExperimentRequestRequestTypeDef",
     "StartLaunchRequestRequestTypeDef",
     "StopExperimentRequestRequestTypeDef",
     "StopLaunchRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
+    "TestSegmentPatternRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateProjectRequestRequestTypeDef",
     "BatchEvaluateFeatureRequestRequestTypeDef",
@@ -95,6 +103,10 @@ __all__ = (
     "StartExperimentResponseTypeDef",
     "StopExperimentResponseTypeDef",
     "StopLaunchResponseTypeDef",
+    "TestSegmentPatternResponseTypeDef",
+    "CreateSegmentResponseTypeDef",
+    "GetSegmentResponseTypeDef",
+    "ListSegmentsResponseTypeDef",
     "EvaluateFeatureResponseTypeDef",
     "EvaluationResultTypeDef",
     "VariationConfigTypeDef",
@@ -106,7 +118,10 @@ __all__ = (
     "ListFeaturesRequestListFeaturesPaginateTypeDef",
     "ListLaunchesRequestListLaunchesPaginateTypeDef",
     "ListProjectsRequestListProjectsPaginateTypeDef",
+    "ListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef",
+    "ListSegmentsRequestListSegmentsPaginateTypeDef",
     "ListProjectsResponseTypeDef",
+    "ListSegmentReferencesResponseTypeDef",
     "MetricGoalConfigTypeDef",
     "MetricMonitorConfigTypeDef",
     "MetricGoalTypeDef",
@@ -115,8 +130,8 @@ __all__ = (
     "UpdateProjectDataDeliveryRequestRequestTypeDef",
     "ProjectDataDeliveryTypeDef",
     "PutProjectEventsResponseTypeDef",
-    "ScheduledSplitsLaunchConfigTypeDef",
-    "ScheduledSplitsLaunchDefinitionTypeDef",
+    "ScheduledSplitConfigTypeDef",
+    "ScheduledSplitTypeDef",
     "BatchEvaluateFeatureResponseTypeDef",
     "CreateFeatureRequestRequestTypeDef",
     "UpdateFeatureRequestRequestTypeDef",
@@ -127,9 +142,8 @@ __all__ = (
     "ExperimentTypeDef",
     "CreateProjectRequestRequestTypeDef",
     "ProjectTypeDef",
-    "CreateLaunchRequestRequestTypeDef",
-    "UpdateLaunchRequestRequestTypeDef",
-    "LaunchTypeDef",
+    "ScheduledSplitsLaunchConfigTypeDef",
+    "ScheduledSplitsLaunchDefinitionTypeDef",
     "CreateFeatureResponseTypeDef",
     "GetFeatureResponseTypeDef",
     "UpdateFeatureResponseTypeDef",
@@ -141,6 +155,9 @@ __all__ = (
     "GetProjectResponseTypeDef",
     "UpdateProjectDataDeliveryResponseTypeDef",
     "UpdateProjectResponseTypeDef",
+    "CreateLaunchRequestRequestTypeDef",
+    "UpdateLaunchRequestRequestTypeDef",
+    "LaunchTypeDef",
     "CreateLaunchResponseTypeDef",
     "GetLaunchResponseTypeDef",
     "ListLaunchesResponseTypeDef",
@@ -250,6 +267,55 @@ class LaunchGroupConfigTypeDef(
     pass
 
 
+_RequiredCreateSegmentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSegmentRequestRequestTypeDef",
+    {
+        "name": str,
+        "pattern": str,
+    },
+)
+_OptionalCreateSegmentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSegmentRequestRequestTypeDef",
+    {
+        "description": str,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateSegmentRequestRequestTypeDef(
+    _RequiredCreateSegmentRequestRequestTypeDef, _OptionalCreateSegmentRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredSegmentTypeDef = TypedDict(
+    "_RequiredSegmentTypeDef",
+    {
+        "arn": str,
+        "createdTime": datetime,
+        "lastUpdatedTime": datetime,
+        "name": str,
+        "pattern": str,
+    },
+)
+_OptionalSegmentTypeDef = TypedDict(
+    "_OptionalSegmentTypeDef",
+    {
+        "description": str,
+        "experimentCount": int,
+        "launchCount": int,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class SegmentTypeDef(_RequiredSegmentTypeDef, _OptionalSegmentTypeDef):
+    pass
+
+
 DeleteExperimentRequestRequestTypeDef = TypedDict(
     "DeleteExperimentRequestRequestTypeDef",
     {
@@ -281,6 +347,13 @@ DeleteProjectRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteSegmentRequestRequestTypeDef = TypedDict(
+    "DeleteSegmentRequestRequestTypeDef",
+    {
+        "segment": str,
+    },
+)
+
 _RequiredEvaluateFeatureRequestRequestTypeDef = TypedDict(
     "_RequiredEvaluateFeatureRequestRequestTypeDef",
     {
@@ -472,6 +545,13 @@ GetProjectRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetSegmentRequestRequestTypeDef = TypedDict(
+    "GetSegmentRequestRequestTypeDef",
+    {
+        "segment": str,
+    },
+)
+
 LaunchExecutionTypeDef = TypedDict(
     "LaunchExecutionTypeDef",
     {
@@ -617,6 +697,63 @@ class ProjectSummaryTypeDef(_RequiredProjectSummaryTypeDef, _OptionalProjectSumm
     pass
 
 
+_RequiredListSegmentReferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredListSegmentReferencesRequestRequestTypeDef",
+    {
+        "segment": str,
+        "type": SegmentReferenceResourceTypeType,
+    },
+)
+_OptionalListSegmentReferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalListSegmentReferencesRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListSegmentReferencesRequestRequestTypeDef(
+    _RequiredListSegmentReferencesRequestRequestTypeDef,
+    _OptionalListSegmentReferencesRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredRefResourceTypeDef = TypedDict(
+    "_RequiredRefResourceTypeDef",
+    {
+        "name": str,
+        "type": str,
+    },
+)
+_OptionalRefResourceTypeDef = TypedDict(
+    "_OptionalRefResourceTypeDef",
+    {
+        "arn": str,
+        "endTime": str,
+        "lastUpdatedOn": str,
+        "startTime": str,
+        "status": str,
+    },
+    total=False,
+)
+
+
+class RefResourceTypeDef(_RequiredRefResourceTypeDef, _OptionalRefResourceTypeDef):
+    pass
+
+
+ListSegmentsRequestRequestTypeDef = TypedDict(
+    "ListSegmentsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -688,33 +825,15 @@ PutProjectEventsResultEntryTypeDef = TypedDict(
     total=False,
 )
 
-ScheduledSplitConfigTypeDef = TypedDict(
-    "ScheduledSplitConfigTypeDef",
+SegmentOverrideTypeDef = TypedDict(
+    "SegmentOverrideTypeDef",
     {
-        "groupWeights": Mapping[str, int],
-        "startTime": Union[datetime, str],
+        "evaluationOrder": int,
+        "segment": str,
+        "weights": Mapping[str, int],
     },
 )
 
-_RequiredScheduledSplitTypeDef = TypedDict(
-    "_RequiredScheduledSplitTypeDef",
-    {
-        "startTime": datetime,
-    },
-)
-_OptionalScheduledSplitTypeDef = TypedDict(
-    "_OptionalScheduledSplitTypeDef",
-    {
-        "groupWeights": Dict[str, int],
-    },
-    total=False,
-)
-
-
-class ScheduledSplitTypeDef(_RequiredScheduledSplitTypeDef, _OptionalScheduledSplitTypeDef):
-    pass
-
-
 StartExperimentRequestRequestTypeDef = TypedDict(
     "StartExperimentRequestRequestTypeDef",
     {
@@ -786,6 +905,14 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+TestSegmentPatternRequestRequestTypeDef = TypedDict(
+    "TestSegmentPatternRequestRequestTypeDef",
+    {
+        "pattern": str,
+        "payload": str,
+    },
+)
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -855,6 +982,39 @@ StopLaunchResponseTypeDef = TypedDict(
     },
 )
 
+TestSegmentPatternResponseTypeDef = TypedDict(
+    "TestSegmentPatternResponseTypeDef",
+    {
+        "match": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateSegmentResponseTypeDef = TypedDict(
+    "CreateSegmentResponseTypeDef",
+    {
+        "segment": SegmentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSegmentResponseTypeDef = TypedDict(
+    "GetSegmentResponseTypeDef",
+    {
+        "segment": SegmentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListSegmentsResponseTypeDef = TypedDict(
+    "ListSegmentsResponseTypeDef",
+    {
+        "nextToken": str,
+        "segments": List[SegmentTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 EvaluateFeatureResponseTypeDef = TypedDict(
     "EvaluateFeatureResponseTypeDef",
     {
@@ -1029,6 +1189,37 @@ ListProjectsRequestListProjectsPaginateTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef = TypedDict(
+    "_RequiredListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef",
+    {
+        "segment": str,
+        "type": SegmentReferenceResourceTypeType,
+    },
+)
+_OptionalListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef = TypedDict(
+    "_OptionalListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef(
+    _RequiredListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef,
+    _OptionalListSegmentReferencesRequestListSegmentReferencesPaginateTypeDef,
+):
+    pass
+
+
+ListSegmentsRequestListSegmentsPaginateTypeDef = TypedDict(
+    "ListSegmentsRequestListSegmentsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 ListProjectsResponseTypeDef = TypedDict(
     "ListProjectsResponseTypeDef",
     {
@@ -1038,6 +1229,15 @@ ListProjectsResponseTypeDef = TypedDict(
     },
 )
 
+ListSegmentReferencesResponseTypeDef = TypedDict(
+    "ListSegmentReferencesResponseTypeDef",
+    {
+        "nextToken": str,
+        "referencedBy": List[RefResourceTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredMetricGoalConfigTypeDef = TypedDict(
     "_RequiredMetricGoalConfigTypeDef",
     {
@@ -1140,21 +1340,48 @@ PutProjectEventsResponseTypeDef = TypedDict(
     },
 )
 
-ScheduledSplitsLaunchConfigTypeDef = TypedDict(
-    "ScheduledSplitsLaunchConfigTypeDef",
+_RequiredScheduledSplitConfigTypeDef = TypedDict(
+    "_RequiredScheduledSplitConfigTypeDef",
     {
-        "steps": Sequence[ScheduledSplitConfigTypeDef],
+        "groupWeights": Mapping[str, int],
+        "startTime": Union[datetime, str],
     },
 )
-
-ScheduledSplitsLaunchDefinitionTypeDef = TypedDict(
-    "ScheduledSplitsLaunchDefinitionTypeDef",
+_OptionalScheduledSplitConfigTypeDef = TypedDict(
+    "_OptionalScheduledSplitConfigTypeDef",
     {
-        "steps": List[ScheduledSplitTypeDef],
+        "segmentOverrides": Sequence[SegmentOverrideTypeDef],
     },
     total=False,
 )
 
+
+class ScheduledSplitConfigTypeDef(
+    _RequiredScheduledSplitConfigTypeDef, _OptionalScheduledSplitConfigTypeDef
+):
+    pass
+
+
+_RequiredScheduledSplitTypeDef = TypedDict(
+    "_RequiredScheduledSplitTypeDef",
+    {
+        "startTime": datetime,
+    },
+)
+_OptionalScheduledSplitTypeDef = TypedDict(
+    "_OptionalScheduledSplitTypeDef",
+    {
+        "groupWeights": Dict[str, int],
+        "segmentOverrides": List[SegmentOverrideTypeDef],
+    },
+    total=False,
+)
+
+
+class ScheduledSplitTypeDef(_RequiredScheduledSplitTypeDef, _OptionalScheduledSplitTypeDef):
+    pass
+
+
 BatchEvaluateFeatureResponseTypeDef = TypedDict(
     "BatchEvaluateFeatureResponseTypeDef",
     {
@@ -1273,6 +1500,7 @@ _OptionalCreateExperimentRequestRequestTypeDef = TypedDict(
         "onlineAbConfig": OnlineAbConfigTypeDef,
         "randomizationSalt": str,
         "samplingRate": int,
+        "segment": str,
         "tags": Mapping[str, str],
     },
     total=False,
@@ -1299,7 +1527,9 @@ _OptionalUpdateExperimentRequestRequestTypeDef = TypedDict(
         "metricGoals": Sequence[MetricGoalConfigTypeDef],
         "onlineAbConfig": OnlineAbConfigTypeDef,
         "randomizationSalt": str,
+        "removeSegment": bool,
         "samplingRate": int,
+        "segment": str,
         "treatments": Sequence[TreatmentConfigTypeDef],
     },
     total=False,
@@ -1334,6 +1564,7 @@ _OptionalExperimentTypeDef = TypedDict(
         "randomizationSalt": str,
         "samplingRate": int,
         "schedule": ExperimentScheduleTypeDef,
+        "segment": str,
         "statusReason": str,
         "tags": Dict[str, str],
         "treatments": List[TreatmentTypeDef],
@@ -1399,91 +1630,21 @@ class ProjectTypeDef(_RequiredProjectTypeDef, _OptionalProjectTypeDef):
     pass
 
 
-_RequiredCreateLaunchRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLaunchRequestRequestTypeDef",
+ScheduledSplitsLaunchConfigTypeDef = TypedDict(
+    "ScheduledSplitsLaunchConfigTypeDef",
     {
-        "groups": Sequence[LaunchGroupConfigTypeDef],
-        "name": str,
-        "project": str,
+        "steps": Sequence[ScheduledSplitConfigTypeDef],
     },
 )
-_OptionalCreateLaunchRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLaunchRequestRequestTypeDef",
+
+ScheduledSplitsLaunchDefinitionTypeDef = TypedDict(
+    "ScheduledSplitsLaunchDefinitionTypeDef",
     {
-        "description": str,
-        "metricMonitors": Sequence[MetricMonitorConfigTypeDef],
-        "randomizationSalt": str,
-        "scheduledSplitsConfig": ScheduledSplitsLaunchConfigTypeDef,
-        "tags": Mapping[str, str],
+        "steps": List[ScheduledSplitTypeDef],
     },
     total=False,
 )
 
-
-class CreateLaunchRequestRequestTypeDef(
-    _RequiredCreateLaunchRequestRequestTypeDef, _OptionalCreateLaunchRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredUpdateLaunchRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLaunchRequestRequestTypeDef",
-    {
-        "launch": str,
-        "project": str,
-    },
-)
-_OptionalUpdateLaunchRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLaunchRequestRequestTypeDef",
-    {
-        "description": str,
-        "groups": Sequence[LaunchGroupConfigTypeDef],
-        "metricMonitors": Sequence[MetricMonitorConfigTypeDef],
-        "randomizationSalt": str,
-        "scheduledSplitsConfig": ScheduledSplitsLaunchConfigTypeDef,
-    },
-    total=False,
-)
-
-
-class UpdateLaunchRequestRequestTypeDef(
-    _RequiredUpdateLaunchRequestRequestTypeDef, _OptionalUpdateLaunchRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredLaunchTypeDef = TypedDict(
-    "_RequiredLaunchTypeDef",
-    {
-        "arn": str,
-        "createdTime": datetime,
-        "lastUpdatedTime": datetime,
-        "name": str,
-        "status": LaunchStatusType,
-        "type": Literal["aws.evidently.splits"],
-    },
-)
-_OptionalLaunchTypeDef = TypedDict(
-    "_OptionalLaunchTypeDef",
-    {
-        "description": str,
-        "execution": LaunchExecutionTypeDef,
-        "groups": List[LaunchGroupTypeDef],
-        "metricMonitors": List[MetricMonitorTypeDef],
-        "project": str,
-        "randomizationSalt": str,
-        "scheduledSplitsDefinition": ScheduledSplitsLaunchDefinitionTypeDef,
-        "statusReason": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class LaunchTypeDef(_RequiredLaunchTypeDef, _OptionalLaunchTypeDef):
-    pass
-
-
 CreateFeatureResponseTypeDef = TypedDict(
     "CreateFeatureResponseTypeDef",
     {
@@ -1573,6 +1734,91 @@ UpdateProjectResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateLaunchRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLaunchRequestRequestTypeDef",
+    {
+        "groups": Sequence[LaunchGroupConfigTypeDef],
+        "name": str,
+        "project": str,
+    },
+)
+_OptionalCreateLaunchRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLaunchRequestRequestTypeDef",
+    {
+        "description": str,
+        "metricMonitors": Sequence[MetricMonitorConfigTypeDef],
+        "randomizationSalt": str,
+        "scheduledSplitsConfig": ScheduledSplitsLaunchConfigTypeDef,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateLaunchRequestRequestTypeDef(
+    _RequiredCreateLaunchRequestRequestTypeDef, _OptionalCreateLaunchRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateLaunchRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLaunchRequestRequestTypeDef",
+    {
+        "launch": str,
+        "project": str,
+    },
+)
+_OptionalUpdateLaunchRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLaunchRequestRequestTypeDef",
+    {
+        "description": str,
+        "groups": Sequence[LaunchGroupConfigTypeDef],
+        "metricMonitors": Sequence[MetricMonitorConfigTypeDef],
+        "randomizationSalt": str,
+        "scheduledSplitsConfig": ScheduledSplitsLaunchConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateLaunchRequestRequestTypeDef(
+    _RequiredUpdateLaunchRequestRequestTypeDef, _OptionalUpdateLaunchRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredLaunchTypeDef = TypedDict(
+    "_RequiredLaunchTypeDef",
+    {
+        "arn": str,
+        "createdTime": datetime,
+        "lastUpdatedTime": datetime,
+        "name": str,
+        "status": LaunchStatusType,
+        "type": Literal["aws.evidently.splits"],
+    },
+)
+_OptionalLaunchTypeDef = TypedDict(
+    "_OptionalLaunchTypeDef",
+    {
+        "description": str,
+        "execution": LaunchExecutionTypeDef,
+        "groups": List[LaunchGroupTypeDef],
+        "metricMonitors": List[MetricMonitorTypeDef],
+        "project": str,
+        "randomizationSalt": str,
+        "scheduledSplitsDefinition": ScheduledSplitsLaunchDefinitionTypeDef,
+        "statusReason": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class LaunchTypeDef(_RequiredLaunchTypeDef, _OptionalLaunchTypeDef):
+    pass
+
+
 CreateLaunchResponseTypeDef = TypedDict(
     "CreateLaunchResponseTypeDef",
     {
